import { useSearch } from "wouter";
import { Input } from "@/components/ui/input.tsx";
import { Button } from "@/components/ui/button.tsx";
import { GalleryCard } from "@/components/gallery/GalleryCard.tsx";
import TagBadge from "@/components/gallery/TagBadge.tsx";
import { useSearchGallery } from "../hook/useSearchGallery";

export default function Gallery() {
    const search = useSearch();
    const searchParams = new URLSearchParams(search);
    const word = searchParams.get("word") ?? undefined;
    const tags = searchParams.get("allow_tag") ?? undefined;
    const limit = searchParams.get("limit");
    const cursor = searchParams.get("cursor");
    const { data, error, isLoading } = useSearchGallery({
        word, tags,
        limit: limit ? Number.parseInt(limit) : undefined,
        cursor: cursor ? Number.parseInt(cursor) : undefined
    });

    if (isLoading) {
        return <div className="p-4">Loading...</div>
    }
    if (error) {
        return <div className="p-4">Error: {String(error)}</div>
    }

    return (<div className="p-4 grid gap-2 overflow-auto h-screen items-start content-start">
        <div className="flex space-x-2">
            <Input className="flex-1"/>
            <Button className="flex-none">Search</Button>
        </div>
        {(word || tags) &&
            <div className="bg-primary rounded-full p-1 sticky top-0 shadow-md">
                {word && <span className="text-primary-foreground ml-4">Search: {word}</span>}
                {tags && <span className="text-primary-foreground ml-4">Tags: <ul className="inline-flex">{tags.split(",").map(x=> <TagBadge tagname={x} key={x}/>)}</ul></span>}
            </div>
        }
        {
            data?.length === 0 && <div className="p-4 text-3xl">No results</div>
        }
        {
            data?.map((x) => {
                return (
                    <GalleryCard doc={x} key={x.id} />
                );
            })
        }
    </div>
    );
}
